#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import glob, os, shutil

from fmtomo_tools.fmtomo_grid_utils import read_vgrid, write_vgrid

pjoin = os.path.join

pwd = '/data/AlpArray_Data/fmtomo/v6/crust_incl_hf_sm_FIX_DTS_grad_sm30_dm10_EASI_test_Plomerova/'

vgrid_file_in = pjoin(pwd, 'vgrids_dts_crust.in')
vgrid_file_out = pjoin(pwd, 'vgrids_dts_crust_variance_slice.in')

latmin_rec, latmax_rec = 44.8, 51.3
lonmin_rec, lonmax_rec = 11.94, 14.66

latmin_grid, latmax_grid = 44.45, 52.55
lonmin_grid, lonmax_grid = 10.83, 15.77


def modify_pickfiles():
    picks_path = pjoin(pwd, 'picks_orig')
    os.chdir(picks_path)

    outdir = pjoin(pwd, 'picks')


    infiles = glob.glob('*.ttf')
    for infile in infiles:
        lines_out = []
        with open(infile, 'r') as fid:
            eventid = infile.split('.ttf')[0]
            npicks = int(fid.readline())

            # copy source/phase header
            for _ in range(2):
                lines_out.append(fid.readline())

            for line in fid:
                lat, lon = [float(item) for item in line.split()[:2]]
                if latmin_rec < lat < latmax_rec and lonmin_rec < lon < lonmax_rec:
                    lines_out.append(line)

        fn_out = pjoin(outdir, infile)
        with open(fn_out, 'w') as outfile:
            # number of picks: list contents - 2 header lines
            outfile.write(f'{len(lines_out) - 2}\n')
            for line in lines_out:
                outfile.write(line)

        print(f'Modified {eventid}: Removed {npicks - len(lines_out)} out of {npicks} picks/stations')

    os.chdir(pwd)


def modify_variance_slice():
    grid, gridN, gridDelta, gridStart = read_vgrid(vgrid_file_in)

    for index, latlon in enumerate(zip(grid['lats'], grid['lons'])):
        lat, lon = latlon
        if not latmin_grid < lat < latmax_grid or not lonmin_grid < lon < lonmax_grid:
            grid['covs'][index] = 1e-6

    write_vgrid(grid, gridN, gridDelta, gridStart, vgrid_file_out)


#modify_pickfiles()
modify_variance_slice()
